@@ -1,11 +1,12 @@
 package My::Module::Meta;
 
-use 5.006;
+use 5.006002;
 
 use strict;
 use warnings;
 
 use Carp;
+use Config;
 use POSIX qw{ uname };
 
 sub new {
@@ -18,9 +19,22 @@ sub new {
     return $self;
 }
 
+sub abstract {
+    return 'Manipulate Mac OS X pasteboards';
+}
+
+sub add_to_cleanup {
+    return [ qw{ cover_db *.gcov *.gcda *.gcno xt/author/optionals } ];
+}
+
+sub author {
+    return 'Tom Wyant (wyant at cpan dot org)';
+}
+
 sub build_requires {
-    my ( $self, @extra ) = @_;
+    my ( undef, @extra ) = @_;		# Invocant not used
     return +{
+	'ExtUtils::CBuilder'	=> 0,
 	'Test::More'	=> 0.96,	# Because of subtest().
 	@extra,
     };
@@ -28,11 +42,18 @@ sub build_requires {
 
 sub ccflags {
     my @ccflags;
+
     my ( $darwin_version ) = split qr{ [.] }smx, ( uname() )[2];
     $darwin_version >= 8
 	and push @ccflags, '-DTIGER';
-    -f '/usr/include/MacTypes.h'
-	and push @ccflags, '-DUSE_MACTYPES';
+
+    $darwin_version >= 19
+	and push @ccflags, '-DCATALINA';
+
+    system "$Config{cc} -fsyntax-only inc/trytypes.c 2>/dev/null";
+    $?
+	or push @ccflags, '-DUSE_MACTYPES';
+
     if ( my $debug = $ENV{DEVELOPER_DEBUG} ) {
 	push @ccflags, '-DDEBUG_PBL';
 	$debug =~ m/ \b backtrace \b /smxi
@@ -41,42 +62,88 @@ sub ccflags {
     return @ccflags;
 }
 
+sub configure_requires {
+    return +{
+	'Config'		=> 0,
+	'File::Basename'	=> 0,
+	'Getopt::Std'		=> 0,
+	'lib'		=> 0,
+	'strict'	=> 0,
+	'warnings'	=> 0,
+    };
+}
+
+sub dist_name {
+    return 'Mac-Pasteboard';
+}
+
 sub distribution {
     my ( $self ) = @_;
     return $self->{distribution};
 }
 
+
+sub license {
+    return 'perl';
+}
+
 sub meta_merge {
+    my ( undef, @extra ) = @_;
     return {
 	'meta-spec'	=> {
 	    version	=> 2,
 	},
 	dynamic_config	=> 1,
-	no_index	=> {
-	    directory	=> [ qw{ inc t xt } ],
-	},
 	resources	=> {
 	    bugtracker	=> {
-                web	=> 'https://rt.cpan.org/Public/Dist/Display.html?Name=Mac-Pasteboard',
-                mailto  => 'wyant@cpan.org',
-            },
+		web	=> 'https://github.com/trwyant/perl-Mac-Pasteboard/issues',
+		mailto  => 'wyant@cpan.org',
+	    },
 	    license	=> 'http://dev.perl.org/licenses/',
 	    repository	=> {
 		type	=> 'git',
 		url	=> 'git://github.com/trwyant/perl-Mac-Pasteboard.git',
 		web	=> 'https://github.com/trwyant/perl-Mac-Pasteboard',
 	    },
-	}
+	},
+	@extra,
     };
 }
 
+
+sub module_name {
+    return 'Mac::Pasteboard';
+}
+
+sub no_index {
+    return +{
+      directory => [
+                     'inc',
+                     't',
+                     'xt',
+                   ],
+    };
+}
+
+sub provides {
+    -d 'lib'
+	or return;
+    local $@ = undef;
+    my $provides = eval {
+	require Module::Metadata;
+	Module::Metadata->provides( version => 2, dir => 'lib' );
+    } or return;
+    return ( provides => $provides );
+}
+
 sub requires {
-    my ( $self, @extra ) = @_;
+    my ( undef, @extra ) = @_;		# Invocant not used
 ##  if ( ! $self->distribution() ) {
 ##  }
+    "$]" >= 5.008
+	and push @extra, Encode => 0;
     return {
 	'Carp'		=> 0,
-	'Encode'	=> 0,
 	'Scalar::Util'	=> 1.01,
 	'strict'	=> 0,
 	'warnings'	=> 0,
@@ -85,11 +152,22 @@ sub requires {
 }
 
 sub requires_perl {
-    return 5.006;
+    return 5.006002;
+}
+
+sub script_files {
+    return [
+	'script/pbtool',
+    ];
+}
+
+sub version_from {
+    return 'lib/Mac/Pasteboard.pm';
 }
 
 sub want_pbtool {
-    my ( undef, $opt, $bldr ) = @_;	# Invocant not used
+##  my ( undef, $opt, $bldr ) = @_;
+    my ( undef, $opt ) = @_;	# Invocant and builder not used
 
     print <<"EOD";
 
@@ -173,6 +251,19 @@ This class supports the following public methods:
 
 This method instantiates the class.
 
+=head2 abstract
+
+This method returns the distribution's abstract.
+
+=head2 add_to_cleanup
+
+This method returns a reference to an array of files to be added to the
+cleanup.
+
+=head2 author
+
+This method returns the name of the distribution author
+
 =head2 build_requires
 
  use YAML;
@@ -191,6 +282,20 @@ C<< {META_MERGE}->{build_requires} >> or C<BUILD_REQUIRES> key.
 This method computes and returns the flags to be passed to the C
 compiler.
 
+=head2 configure_requires
+
+ use YAML;
+ print Dump( $meta->configure_requires() );
+
+This method returns a reference to a hash describing the modules
+required to configure the package, suitable for use in a F<Build.PL>
+C<configure_requires> key, or a F<Makefile.PL>
+C<< {META_MERGE}->{configure_requires} >> or C<CONFIGURE_REQUIRES> key.
+
+=head2 dist_name
+
+This method returns the distribution name.
+
 =head2 distribution
 
  if ( $meta->distribution() ) {
@@ -202,6 +307,10 @@ compiler.
 This method returns the value of the environment variable
 C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
+=head2 license
+
+This method returns the distribution's license.
+
 =head2 meta_merge
 
  use YAML;
@@ -209,8 +318,30 @@ C<MAKING_MODULE_DISTRIBUTION> at the time the object was instantiated.
 
 This method returns a reference to a hash describing the meta-data which
 has to be provided by making use of the builder's C<meta_merge>
-functionality. This includes the C<bugtracker>, C<dynamic_config>,
-C<no_index> and C<resources> data.
+functionality. This includes the C<dynamic_config> and C<resources>
+data.
+
+Any arguments will be appended to the generated array.
+
+=head2 module_name
+
+This method returns the name of the module the distribution is based
+on.
+
+=head2 no_index
+
+This method returns the names of things which are not to be indexed
+by CPAN.
+
+=head2 provides
+
+ use YAML;
+ print Dump( [ $meta->provides() ] );
+
+This method attempts to load L<Module::Metadata|Module::Metadata>. If
+this succeeds, it returns a C<provides> entry suitable for inclusion in
+L<meta_merge()|/meta_merge> data (i.e. C<'provides'> followed by a hash
+reference). If it can not load the required module, it returns nothing.
 
 =head2 requires
 
@@ -231,6 +362,16 @@ may be added.
 
 This method returns the version of Perl required by the package.
 
+=head2 script_files
+
+This method returns a reference to an array containing the names of
+script files provided by this distribution. This array may be empty.
+
+=head2 version_from
+
+This method returns the name of the distribution file from which the
+distribution's version is to be derived.
+
 =head1 ATTRIBUTES
 
 This class has no public attributes.
@@ -248,7 +389,8 @@ information makes it into F<META.yml>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<http://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Mac-Pasteboard/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -256,7 +398,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010-2016 by Thomas R. Wyant, III
+Copyright (C) 2010-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
